Search.setIndex({docnames:["antisplodge","index","modules"],envversion:{"sphinx.domains.c":2,"sphinx.domains.changeset":1,"sphinx.domains.citation":1,"sphinx.domains.cpp":3,"sphinx.domains.index":1,"sphinx.domains.javascript":2,"sphinx.domains.math":2,"sphinx.domains.python":2,"sphinx.domains.rst":2,"sphinx.domains.std":1,"sphinx.ext.todo":2,"sphinx.ext.viewcode":1,sphinx:56},filenames:["antisplodge.rst","index.rst","modules.rst"],objects:{"":{antisplodge:[0,0,0,"-"]},"antisplodge.CelltypeDeconvolver":{Get:[0,2,1,""],Set:[0,2,1,""],forward:[0,2,1,""],training:[0,3,1,""]},"antisplodge.DeconvolutionExperiment":{generateTrainTestValidation:[0,2,1,""],loadCheckpoint:[0,2,1,""],setCellTypeColumn:[0,2,1,""],setVerbosity:[0,2,1,""],setupDataLoaders:[0,2,1,""],setupModel:[0,2,1,""],setupOptimizerAndCriterion:[0,2,1,""],splitTrainTestValidation:[0,2,1,""]},antisplodge:{CelltypeDeconvolver:[0,1,1,""],DeconvolutionExperiment:[0,1,1,""],SingleCellDataset:[0,1,1,""],getConvolutedProfilesFromDistributions:[0,4,1,""],getProportionFromCountVector:[0,4,1,""],multinomialSampler:[0,4,1,""],predict:[0,4,1,""],train:[0,4,1,""]}},objnames:{"0":["py","module","Python module"],"1":["py","class","Python class"],"2":["py","method","Python method"],"3":["py","attribute","Python attribute"],"4":["py","function","Python function"]},objtypes:{"0":"py:module","1":"py:class","2":"py:method","3":"py:attribute","4":"py:function"},terms:{"case":0,"class":0,"default":0,"final":0,"float":0,"function":[1,2],"int":0,"new":0,"return":0,"true":0,"while":0,CDs:0,The:[0,1],Used:0,Will:0,about:0,adam:0,adata:0,afterward:0,all:0,alreadi:0,although:0,anndata:0,anoth:0,anyth:0,arg:0,assum:0,auto_load_model_on_finish:0,back:0,base:0,batch:0,batch_siz:0,beat:0,been:0,befor:0,best:0,best_loss:0,better:0,between:0,bind:0,block:0,bool:0,call:0,can:0,care:0,cd_max:0,cd_min:0,cell:0,cell_typ:0,cell_type_kei:0,celltyp:0,celltypedeconvolv:0,celltypes_column:0,check:0,checkpoint:0,column:0,comput:0,contain:0,content:1,contribut:0,control:0,convert:0,convolut:0,correspond:0,count:0,counter:0,cpu:0,creat:0,criterion:0,cuda:0,cuda_id:0,current:0,data:0,dataload:0,dataset:0,deconvolut:0,deconvolutionexperi:0,defin:0,densiti:0,devic:0,dict:0,dictionari:0,distribut:0,done:0,dropout:0,dure:0,each:0,either:0,element:0,epoch:0,equal:0,error:0,everi:0,everyth:0,experi:0,extend:0,extrem:0,fals:0,featur:0,feed:0,file:[0,1],first:0,first_part_s:0,form:0,format:0,former:0,forward:0,found:0,fps:0,frame:0,from:0,full:0,gene:0,gener:0,generatetraintestvalid:0,get:0,getconvolutedprofilesfromdistribut:0,getproportionfromcountvector:0,going:0,half:0,has:0,hasn:0,hidden:0,hold:0,hook:0,how:0,i_list:0,ignor:0,immedi:0,includ:0,index:[0,1],indici:0,inform:0,initi:0,initit:0,input:0,input_dropout:0,instanc:0,instead:0,integ:0,intend:0,just:0,keep:0,kei:0,kwd:0,last:0,last_part_s:0,latter:0,layer:0,learn:0,learning_r:0,length:0,level:0,like:0,list:0,load:0,loadcheckpoint:0,loader:0,look:0,loss:0,lower:0,lps:0,main:1,make:0,mani:0,maximum:0,measur:0,member:0,method:0,minimum:0,miniumum:0,miss:0,model:0,modul:[0,1],more:0,multinomi:0,multinomialsampl:0,name:0,need:0,network:0,neural:0,neuron:0,node:0,none:0,normalize_x:0,num_class:0,num_featur:0,num_profil:0,number:0,number_of_layers_per_part:0,object:0,obs:0,observ:0,onc:0,one:0,onto:0,ops:0,optim:0,option:0,order:0,out:0,out_part_s:0,output:0,overridden:0,packag:[1,2],page:1,pair:0,paramdescript:0,paramet:0,paramtyp:0,part:0,particular:0,pass:0,path:0,patienc:0,per:0,perform:0,posit:0,predict:0,print:0,process:0,produc:0,profil:0,proport:0,pytorch:0,rang:0,rate:0,readi:0,recip:0,recommend:0,regist:0,relat:0,rememb:0,requir:0,respect:0,rest:0,restart:0,retriev:0,run:0,same:0,sampl:0,sampler:0,save:0,save_fil:0,sc_test:0,sc_train:0,sc_val:0,scale:0,search:1,second:0,second_part_s:0,see:0,seen:0,set:0,setcelltypecolumn:0,setupdataload:0,setupmodel:0,setupoptimizerandcriterion:0,setverbos:0,should:0,silent:0,similr:0,simpl:0,simul:0,sinc:0,singl:0,singlecelldataset:0,singleton:0,smaller:0,smoothl1loss:0,sourc:0,spare:0,split:0,splittraintestvalid:0,spot:0,sps:0,stamp:0,state:0,step:0,stop:0,store:[0,1],str:0,strattifi:0,subclass:0,subsequ:0,sum:0,suppli:0,take:0,temperatur:0,tensor:0,test:0,test_load:0,testindex:0,than:0,thei:0,them:0,thi:0,three:0,time:0,togeth:0,torch:0,traceback:0,track:0,train:0,train_load:0,train_loss:0,trainindex:0,type:0,use:0,used:0,using:0,usual:0,util:0,val:0,val_load:0,valid:0,validation_loss:0,valindex:0,valu:0,variabl:0,vector:0,verboisti:0,verbos:0,want:0,warm:0,were:0,what:0,when:0,where:0,which:0,within:0,x_data:0,x_list:0,x_test:0,x_test_count:0,x_train:0,x_train_count:0,x_val:0,x_val_count:0,y_data:0,y_list:0,y_test:0,y_test_prop:0,y_train:0,y_train_prop:0,y_val:0,y_val_prop:0,you:0,yourself:0},titles:["antisplodge package","Welcome to AntiSplodge\u2019s documentation!","antisplodge"],titleterms:{"function":0,antisplodg:[0,1,2],document:1,indic:1,packag:0,tabl:1,welcom:1}})